aboutsummaryrefslogtreecommitdiff
path: root/gcc/optabs.h
diff options
context:
space:
mode:
Diffstat (limited to 'gcc/optabs.h')
-rw-r--r--gcc/optabs.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/gcc/optabs.h b/gcc/optabs.h
index 5d5593b..4b46bda 100644
--- a/gcc/optabs.h
+++ b/gcc/optabs.h
@@ -377,6 +377,9 @@ enum optab_index
OTI_vec_pack_sfix_trunc,
OTI_vec_pack_ufix_trunc,
+ /* Vector shuffling. */
+ OTI_vec_perm,
+
/* Perform a raise to the power of integer. */
OTI_powi,
@@ -557,6 +560,7 @@ enum optab_index
#define vec_pack_usat_optab (&optab_table[OTI_vec_pack_usat])
#define vec_pack_sfix_trunc_optab (&optab_table[OTI_vec_pack_sfix_trunc])
#define vec_pack_ufix_trunc_optab (&optab_table[OTI_vec_pack_ufix_trunc])
+#define vec_perm_optab (&direct_optab_table[(int) OTI_vec_perm])
#define powi_optab (&optab_table[OTI_powi])
@@ -617,7 +621,6 @@ enum convert_optab_index
#define vec_store_lanes_optab (&convert_optab_table[COI_vec_store_lanes])
#define vcond_optab (&convert_optab_table[(int) COI_vcond])
#define vcondu_optab (&convert_optab_table[(int) COI_vcondu])
-#define vshuffle_optab (&direct_optab_table[(int) DOI_vshuffle])
/* Contains the optab used for each rtx code. */
extern optab code_to_optab[NUM_RTX_CODE + 1];
@@ -639,9 +642,6 @@ enum direct_optab_index
DOI_reload_in,
DOI_reload_out,
- /* Vector shuffling. */
- DOI_vshuffle,
-
/* Block move operation. */
DOI_movmem,
@@ -888,11 +888,11 @@ extern rtx expand_vec_cond_expr (tree, tree, tree, tree, rtx);
/* Generate code for VEC_LSHIFT_EXPR and VEC_RSHIFT_EXPR. */
extern rtx expand_vec_shift_expr (sepops, rtx);
-/* Return tree if target supports vector operations for VEC_SHUFFLE_EXPR. */
-bool expand_vec_shuffle_expr_p (enum machine_mode, tree, tree, tree);
+/* Return tree if target supports vector operations for VEC_PERM_EXPR. */
+bool expand_vec_perm_expr_p (enum machine_mode, tree, tree, tree);
-/* Generate code for VEC_SHUFFLE_EXPR. */
-extern rtx expand_vec_shuffle_expr (tree, tree, tree, tree, rtx);
+/* Generate code for VEC_PERM_EXPR. */
+extern rtx expand_vec_perm_expr (tree, tree, tree, tree, rtx);
/* Return the insn used to implement mode MODE of OP, or CODE_FOR_nothing
if the target does not have such an insn. */